global parts
parts = []

global deltaTime
deltaTime = .1

global prefabs
prefabs = {}

global starts
starts = []

global backgroundColor
backgroundColor = (255, 255, 255)

global mousePosition
mousePosition = (0, 0)

global screenRect
screenRect = (800, 600)